### This is my first development pypi project
    - featured 01- add
    - featured 02- Sub
    - featured 03- Mul
    - featured 04- dev

## Example
```python
from PremiumCalculator import add, sub, mul, dev

print(add(5, 3))  # 8
print(sub(9, 4))  # 5
print(mul(2, 6))  # 12
print(dev(10, 2)) # 5.0
